@@ -145,6 +145,9 @@ void EditorTab::initLater()
 
 EditorTab::~EditorTab()
 {
+    disconnect(m_catalog,&Catalog::signalNumberOfFuzziesChanged,this,&EditorTab::numberOfFuzziesChanged);
+    disconnect(m_catalog,&Catalog::signalNumberOfEmptyChanged,this,&EditorTab::numberOfUntranslatedChanged);
+
     if (!m_catalog->isEmpty())
     {
         emit fileAboutToBeClosed();
@@ -1634,9 +1637,14 @@ void EditorTab::mergeIntoOpenDocument()
             QStringList unoArgs(QStringLiteral("-c")); unoArgs.append(QStringLiteral("import uno"));
             if (QProcess::execute(python, unoArgs)!=0)
             {
-                KMessageBox::information(SettingsController::instance()->mainWindowPtr(),
+                python=QStringLiteral("python3");
+                QStringList unoArgs(QStringLiteral("-c")); unoArgs.append(QStringLiteral("import uno"));
+                if (QProcess::execute(python, unoArgs)!=0)
+                {
+                    KMessageBox::information(SettingsController::instance()->mainWindowPtr(),
                                          i18n("Install python-uno package for additional functionality."));
-                return;
+                    return;
+                }
             }
 
             QStringList reloaderArgs(reloaderScript);
